﻿// Import: Jan Conze / PBS2H23ACO mit Unterstützung durch Radu Catalin Calcan

using Projekt_Calcan_Conze_Import;
using Projekt_Calcan_Conze_Import.Repositories;

try
{
    string? filePath = null;

    while (string.IsNullOrEmpty(filePath))
    {
        Console.WriteLine("Bitte gib einen Dateipfad an:");
        filePath = Console.ReadLine();

        if (filePath?.StartsWith('\"') ?? false)
        {
            filePath = filePath.Substring(startIndex: 1, length: filePath.Length - 1);
        }

        if (filePath?.EndsWith('\"') ?? false)
        {
            filePath = filePath.Substring(startIndex: 0, length: filePath.Length - 1);
        }

        if (!File.Exists(filePath))
        {
            Console.WriteLine("Die Datei existiert nicht.");
            filePath = null;
        }
    }

    string? clientNumber = null;

    while (string.IsNullOrEmpty(clientNumber))
    {
        Console.WriteLine("Bitte gib eine Kundennummer an:");
        clientNumber = Console.ReadLine();
    }

    var (users, protocol) = ImportUsers.FromCsv(filePath);
    var existingUsers = await Database.GetUserIdentifiers(clientNumber);

    var duplicateUsers =
        users.Where(
                user =>
                    existingUsers.Any(
                        existingUser =>
                            existingUser.FirstName == user.FirstName
                            && existingUser.LastName == user.LastName
                            && existingUser.Title == user.Title))
            .ToList();

    foreach (var duplicateUser in duplicateUsers)
    {
        protocol.AddRange(duplicateUser.ToCsv());
    }

    var usersToCreate = users.Except(duplicateUsers).ToList();
    await Database.CreateUsers(usersToCreate, clientNumber);

    if (protocol.Any())
    {
        string protocolFilePath =
            Path.Combine(
                Path.GetDirectoryName(filePath),
                Path.GetFileNameWithoutExtension(filePath) + "_protocol.csv");
        await File.WriteAllLinesAsync(protocolFilePath, protocol);
        Console.WriteLine($"Protokoll wurde unter \"{protocolFilePath}\" gespeichert.");
    }
    else
    {
        Console.WriteLine("Alle Nutzer wurden erfolgreich importiert.");
    }
}
catch (Exception ex)
{
    Console.WriteLine($"Ein Fehler ist aufgetreten: {ex.Message}");
}