﻿// Export: Radu Catalin Calcan / PBS2H23Aca mit Unterstützung durch Jan Conze

using Core;
using Projekt_Calcan_Conze_Export.Repositories;
using System.Globalization;

try
{
    string? clientNumber = null;

    while (string.IsNullOrEmpty(clientNumber))
    {
        Console.WriteLine("Bitte gib eine Kundennummer an:");
        clientNumber = Console.ReadLine();
    }

    Console.WriteLine();

    DateOnly? startDate = null;

    while (startDate is null)
    {
        Console.WriteLine($"Bitte gib das Startdatum im folgenden Format an ({Constants.DateFormat}):");
        startDate =
            DateOnly.TryParseExact(
                Console.ReadLine() ?? string.Empty,
                Constants.DateFormat,
                CultureInfo.InvariantCulture,
                DateTimeStyles.None,
                out var start)
                ? start
                : null;
    }

    Console.WriteLine();

    DateOnly? endDate = null;

    while (endDate is null)
    {
        Console.WriteLine($"Bitte gib das Enddatum im folgenden Format an ({Constants.DateFormat}):");
        endDate =
            DateOnly.TryParseExact(
                Console.ReadLine() ?? string.Empty,
                Constants.DateFormat,
                CultureInfo.InvariantCulture,
                DateTimeStyles.None,
                out var end)
                ? end
                : null;

        if (endDate is not null
            && endDate < startDate)
        {
            Console.WriteLine("Das Enddatum darf nicht vor dem Startdatum liegen.");
            endDate = null;
        }
    }

    Console.WriteLine();

    string? directoryPath = null;

    while (string.IsNullOrEmpty(directoryPath))
    {
        Console.WriteLine("Bitte gib einen Dateipfad für die Ausgabe an:");
        directoryPath = Console.ReadLine();

        if (directoryPath?.StartsWith('\"') ?? false)
        {
            directoryPath = directoryPath.Substring(startIndex: 1, length: directoryPath.Length - 1);
        }

        if (directoryPath?.EndsWith('\"') ?? false)
        {
            directoryPath = directoryPath.Substring(startIndex: 0, length: directoryPath.Length - 1);
        }

        if (!Path.Exists(directoryPath))
        {
            Console.WriteLine("Der angegebene Dateipfad existiert nicht.");
            directoryPath = null;
        }
    }

    Console.WriteLine();

    var billing = await Database.CreateBilling(startDate.Value, endDate.Value, clientNumber);

    if (billing is null)
    {
        Console.WriteLine("Es konnte keine Rechnung erstellt werden.");
    }
    else
    {
        string fileName =
            $"{DateTime.Today.ToString(Constants.DateFormat)}_{clientNumber}_{startDate.Value.ToString(Constants.DateFormat)}_{endDate.Value.ToString(Constants.DateFormat)}.csv";
        string filePath = Path.Combine(directoryPath, fileName);
        File.WriteAllLines(filePath, billing.ToCsvLines());
        Console.WriteLine($"Die Rechnung wurde unter \"{filePath}\" abgelegt.");
    }
}
catch (Exception ex)
{
    Console.WriteLine($"Ein Fehler ist aufgetreten: {ex.Message}");
}